==> haskell-hpack-0.33.0-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.33.0
id: hpack-0.33.0-1atjn5MaWKfEaGe3TDLTvA
key: hpack-0.33.0-1atjn5MaWKfEaGe3TDLTvA
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: A modern format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: 886a69ff24db08211222642107e75c31
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.License Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
                Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
                Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
                Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.6.5/site-local/hpack-0.33.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hpack-0.33.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hpack-0.33.0
hs-libraries: HShpack-0.33.0-1atjn5MaWKfEaGe3TDLTvA
depends:
    Cabal-2.4.0.1 Glob-0.10.0-ChBxYw8caZwGrFwUeslq31
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc base-4.12.0.0
    bifunctors-5.5.6-1hzbr6CRsZhGc3TV5tucLZ bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1
    http-client-0.6.4-IjjBqxaHkliH8n6zGH1bzH
    http-client-tls-0.3.5.3-7atnt0pnk90C1CCA8k9C4D
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    infer-license-0.2.0-EjbgXl8KAJM3Rz1etP6Apv pretty-1.1.3.6
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.2.0-BIsjRIkW1eUC5z8TOsGDnT
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.33.0-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.33.0
id: hpack-0.33.0-GWyrhoOEyjLDBE4YLHUuJt
key: hpack-0.33.0-GWyrhoOEyjLDBE4YLHUuJt
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: A modern format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
abi: 3a4f919400903c250df206aa6af7fb1a
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Render Hpack.Yaml
hidden-modules: Data.Aeson.Config.FromValue
                Data.Aeson.Config.Parser Data.Aeson.Config.Types
                Data.Aeson.Config.Util Hpack.CabalFile Hpack.Defaults Hpack.Haskell
                Hpack.License Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
                Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
                Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
                Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
                Hpack.Util Paths_hpack
import-dirs: /usr/lib/ghc-8.6.5/site-local/hpack-0.33.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/hpack-0.33.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hpack-0.33.0
hs-libraries: HShpack-0.33.0-GWyrhoOEyjLDBE4YLHUuJt
depends:
    Cabal-2.4.0.1 Glob-0.10.0-ChBxYw8caZwGrFwUeslq31
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc base-4.12.0.0
    bifunctors-5.5.6-1hzbr6CRsZhGc3TV5tucLZ bytestring-0.10.8.2
    containers-0.6.0.1 cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    deepseq-1.4.4.0 directory-1.3.3.0 filepath-1.4.2.1
    http-client-0.6.4-IjjBqxaHkliH8n6zGH1bzH
    http-client-tls-0.3.5.3-7atnt0pnk90C1CCA8k9C4D
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    infer-license-0.2.0-EjbgXl8KAJM3Rz1etP6Apv pretty-1.1.3.6
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.2.0-Bo61oBN0Pdc7un4PlgWpOL
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
